API docs for “spamfighter.rules.analyze”

# Module s.r.analyze

Part of spamfighter.rules View Source

Набор правил аналица текста сообщений

Function | messageFloodCheck | Правило проверки сообщения на наличие флуда.

def messageFloodCheck(domain, message, attribute='text', minLength=16, minMean=1.5, maxVariance=2.0): (source)
Правило проверки сообщения на наличие флуда. Наличие флуда в фразе определяется частотой повторения триграмм. При запуске на тестовой базе, содержащей нормальные сообщения, из 16674 сообщений функция не заблокировала ни одного сообщения. При запуске на тестовой базе, содержащей флуд, из 1477 было обнаружено 956 сообщений, что составляет 65% от общего числа сообщений.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего текст (type: `str` )
| minLength | минимальная длина сообщения для анализа (type: `int` )
| minMean | минимальное значение математического ожидания (type: `float` )
| maxVariance | максимальное значение дисперсии (type: `float` )